.. networking-ofagent documentation master file, created by
   sphinx-quickstart on Mon Jan 26 13:04:07 2015.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to networking-ofagent's documentation!
==============================================

Contents:

.. toctree::
   :maxdepth: 2

   readme


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`


Developer Docs
==============

.. toctree::
    :maxdepth: 1

    devref/index
